management: clarify the inconsistency in UDP face timeouts in nfd.conf
refs #2473
Change-Id: Iceeda5f03bc426dfab1e67cf508996d3fe96ac42
diff --git a/nfd.conf.sample.in b/nfd.conf.sample.in
index 908ad7b..fa229b4 100644
--- a/nfd.conf.sample.in
+++ b/nfd.conf.sample.in
@@ -92,7 +92,11 @@
port 6363 ; UDP unicast port number
enable_v4 yes ; set to 'no' to disable IPv4 channels, default 'yes'
enable_v6 yes ; set to 'no' to disable IPv6 channels, default 'yes'
- idle_timeout 600 ; idle time (seconds) before closing a UDP unicast face
+
+ ; idle time (seconds) before closing a UDP unicast face, the actual timeout would be
+ ; anywhere within [idle_timeout, 2*idle_timeout), default is 600
+ idle_timeout 600
+
keep_alive_interval 25; interval (seconds) between keep-alive refreshes
; UDP multicast settings
diff --git a/daemon/mgmt/face-manager.cpp b/daemon/mgmt/face-manager.cpp
index 5256c92..3c590f5 100644
--- a/daemon/mgmt/face-manager.cpp
+++ b/daemon/mgmt/face-manager.cpp
@@ -380,8 +380,8 @@
// udp
// {
// port 6363 ; UDP unicast port number
// idle_timeout 30 ; idle time (seconds) before closing a UDP unicast face
// keep_alive_interval 25; interval (seconds) between keep-alive refreshes
// ; NFD creates one UDP multicast face per NIC
// mcast yes ; set to 'no' to disable UDP multicast, default 'yes'
@@ -392,7 +392,7 @@
std::string port = "6363";
bool enableV4 = true;
bool enableV6 = true;
- size_t timeout = 30;
+ size_t timeout = 600;
size_t keepAliveInterval = 25;
bool useMcast = true;
std::string mcastGroup = "224.0.23.170";
@@ -380,8 +380,8 @@
// {
// port 6363 ; UDP unicast port number
- // idle_timeout 30 ; idle time (seconds) before closing a UDP unicast face
- // keep_alive_interval 25; interval (seconds) between keep-alive refreshes
+ // idle_timeout 600 ; idle time (seconds) before closing a UDP unicast face
+ // keep_alive_interval 25 ; interval (seconds) between keep-alive refreshes
// ; NFD creates one UDP multicast face per NIC
// mcast yes ; set to 'no' to disable UDP multicast, default 'yes'